@@ -6,8 +6,8 @@ from typing import List
 
 def tetun_lid_model() -> object:
     """ Load Tetun language identification model """
-    module_path = Path(__file__).parent
-    model_path = module_path/'model'/'tetun_lid_model.pkl'
+    #module_path = Path(__file__).parent
+    model_path = Path('model/tetun_lid_model.pkl')
     if not model_path.exists():
         print(f"Model file not found at: {model_path}")
         return []
